pub struct CloudRunRevisionEndpoint {
pub service_uri: Option<String>,
pub uri: Option<String>,
}Expand description
Wrapper for Cloud Run revision attributes.
This type is not used in any activity, and only used as part of another schema.
Fields
service_uri: Option<String>Output only. The URI of the Cloud Run service that the revision belongs to. The format is: projects/{project}/locations/{location}/services/{service}
uri: Option<String>A Cloud Run revision URI. The format is: projects/{project}/locations/{location}/revisions/{revision}