pub struct DeliverInfo {
pub google_service_type: Option<String>,
pub ip_address: Option<String>,
pub psc_google_api_target: Option<String>,
pub resource_uri: Option<String>,
pub storage_bucket: Option<String>,
pub target: Option<String>,
}Expand description
Details of the final state “deliver” and associated resource.
This type is not used in any activity, and only used as part of another schema.
Fields
google_service_type: Option<String>Recognized type of a Google Service the packet is delivered to (if applicable).
ip_address: Option<String>IP address of the target (if applicable).
psc_google_api_target: Option<String>PSC Google API target the packet is delivered to (if applicable).
resource_uri: Option<String>URI of the resource that the packet is delivered to.
storage_bucket: Option<String>Name of the Cloud Storage Bucket the packet is delivered to (if applicable).
target: Option<String>Target type where the packet is delivered to.