EffectiveVpcFlowLogsConfig

Struct EffectiveVpcFlowLogsConfig 

pub struct EffectiveVpcFlowLogsConfig {
Show 13 fields pub aggregation_interval: Option<String>, pub cross_project_metadata: Option<String>, pub filter_expr: Option<String>, pub flow_sampling: Option<f32>, pub interconnect_attachment: Option<String>, pub metadata: Option<String>, pub metadata_fields: Option<Vec<String>>, pub name: Option<String>, pub network: Option<String>, pub scope: Option<String>, pub state: Option<String>, pub subnet: Option<String>, pub vpn_tunnel: Option<String>,
}
A configuration to generate a response for GetEffectiveVpcFlowLogsConfig request.

This type is not used in any activity, and only used as part of another schema.

Fields

aggregation_interval: Option<String>

The aggregation interval for the logs. Default value is INTERVAL_5_SEC.

cross_project_metadata: Option<String>

Determines whether to include cross project annotations in the logs. This field is available only for organization configurations. If not specified in org configs will be set to CROSS_PROJECT_METADATA_ENABLED.

filter_expr: Option<String>

Export filter used to define which VPC Flow Logs should be logged.

flow_sampling: Option<f32>

The value of the field must be in (0, 1]. The sampling rate of VPC Flow Logs where 1.0 means all collected logs are reported. Setting the sampling rate to 0.0 is not allowed. If you want to disable VPC Flow Logs, use the state field instead. Default value is 1.0.

interconnect_attachment: Option<String>

Traffic will be logged from the Interconnect Attachment. Format: projects/{project_id}/regions/{region}/interconnectAttachments/{name}

metadata: Option<String>

Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default value is INCLUDE_ALL_METADATA.

metadata_fields: Option<Vec<String>>

Custom metadata fields to include in the reported VPC flow logs. Can only be specified if “metadata” was set to CUSTOM_METADATA.

name: Option<String>

Unique name of the configuration. The name can have one of the following forms: - For project-level configurations: projects/{project_id}/locations/global/vpcFlowLogsConfigs/{vpc_flow_logs_config_id} - For organization-level configurations: organizations/{organization_id}/locations/global/vpcFlowLogsConfigs/{vpc_flow_logs_config_id} - For a Compute config, the name will be the path of the subnet: projects/{project_id}/regions/{region}/subnetworks/{subnet_id}

network: Option<String>

Traffic will be logged from VMs, VPN tunnels and Interconnect Attachments within the network. Format: projects/{project_id}/global/networks/{name}

scope: Option<String>

Specifies the scope of the config (e.g., SUBNET, NETWORK, ORGANIZATION..).

state: Option<String>

The state of the VPC Flow Log configuration. Default value is ENABLED. When creating a new configuration, it must be enabled. Setting state=DISABLED will pause the log generation for this config.

subnet: Option<String>

Traffic will be logged from VMs within the subnetwork. Format: projects/{project_id}/regions/{region}/subnetworks/{name}

vpn_tunnel: Option<String>

Traffic will be logged from the VPN Tunnel. Format: projects/{project_id}/regions/{region}/vpnTunnels/{name}