Endpoint

Struct Endpoint 

pub struct Endpoint {
Show 18 fields pub app_engine_version: Option<AppEngineVersionEndpoint>, pub cloud_function: Option<CloudFunctionEndpoint>, pub cloud_run_revision: Option<CloudRunRevisionEndpoint>, pub cloud_sql_instance: Option<String>, pub forwarding_rule: Option<String>, pub forwarding_rule_target: Option<String>, pub fqdn: Option<String>, pub gke_master_cluster: Option<String>, pub instance: Option<String>, pub ip_address: Option<String>, pub load_balancer_id: Option<String>, pub load_balancer_type: Option<String>, pub network: Option<String>, pub network_type: Option<String>, pub port: Option<i32>, pub project_id: Option<String>, pub redis_cluster: Option<String>, pub redis_instance: Option<String>,
}
Source or destination of the Connectivity Test.

This type is not used in any activity, and only used as part of another schema.

Fields

app_engine_version: Option<AppEngineVersionEndpoint>

An App Engine service version. Applicable only to source endpoint.

cloud_function: Option<CloudFunctionEndpoint>

A Cloud Function. Applicable only to source endpoint.

cloud_run_revision: Option<CloudRunRevisionEndpoint>

A Cloud Run revision Applicable only to source endpoint.

cloud_sql_instance: Option<String>

A Cloud SQL instance URI.

forwarding_rule: Option<String>

A forwarding rule and its corresponding IP address represent the frontend configuration of a Google Cloud load balancer. Forwarding rules are also used for protocol forwarding, Private Service Connect and other network services to provide forwarding information in the control plane. Applicable only to destination endpoint. Format: projects/{project}/global/forwardingRules/{id} or projects/{project}/regions/{region}/forwardingRules/{id}

forwarding_rule_target: Option<String>

Output only. Specifies the type of the target of the forwarding rule.

fqdn: Option<String>

DNS endpoint of Google Kubernetes Engine cluster control plane. Requires gke_master_cluster to be set, can’t be used simultaneoulsly with ip_address or network. Applicable only to destination endpoint.

gke_master_cluster: Option<String>instance: Option<String>

A Compute Engine instance URI.

ip_address: Option<String>

The IP address of the endpoint, which can be an external or internal IP.

load_balancer_id: Option<String>

Output only. ID of the load balancer the forwarding rule points to. Empty for forwarding rules not related to load balancers.

load_balancer_type: Option<String>

Output only. Type of the load balancer the forwarding rule points to.

network: Option<String>

A VPC network URI.

network_type: Option<String>

Type of the network where the endpoint is located. Applicable only to source endpoint, as destination network type can be inferred from the source.

port: Option<i32>

The IP protocol port of the endpoint. Only applicable when protocol is TCP or UDP.

project_id: Option<String>

Project ID where the endpoint is located. The project ID can be derived from the URI if you provide a endpoint or network URI. The following are two cases where you may need to provide the project ID: 1. Only the IP address is specified, and the IP address is within a Google Cloud project. 2. When you are using Shared VPC and the IP address that you provide is from the service project. In this case, the network that the IP address resides in is defined in the host project.

redis_cluster: Option<String>

A Redis Cluster URI. Applicable only to destination endpoint.

redis_instance: Option<String>

A Redis Instance URI. Applicable only to destination endpoint.