pub struct FirewallInfo {Show 13 fields
pub action: Option<String>,
pub direction: Option<String>,
pub display_name: Option<String>,
pub firewall_rule_type: Option<String>,
pub network_uri: Option<String>,
pub policy: Option<String>,
pub policy_priority: Option<i32>,
pub policy_uri: Option<String>,
pub priority: Option<i32>,
pub target_service_accounts: Option<Vec<String>>,
pub target_tags: Option<Vec<String>>,
pub target_type: Option<String>,
pub uri: Option<String>,
}Expand description
For display only. Metadata associated with a VPC firewall rule, an implied VPC firewall rule, or a firewall policy rule.
This type is not used in any activity, and only used as part of another schema.
Fields
action: Option<String>Possible values: ALLOW, DENY, APPLY_SECURITY_PROFILE_GROUP
direction: Option<String>Possible values: INGRESS, EGRESS
display_name: Option<String>The display name of the firewall rule. This field might be empty for firewall policy rules.
firewall_rule_type: Option<String>The firewall rule’s type.
network_uri: Option<String>The URI of the VPC network that the firewall rule is associated with. This field is not applicable to hierarchical firewall policy rules.
policy: Option<String>The name of the firewall policy that this rule is associated with. This field is not applicable to VPC firewall rules and implied VPC firewall rules.
policy_priority: Option<i32>The priority of the firewall policy that this rule is associated with. This field is not applicable to VPC firewall rules and implied VPC firewall rules.
policy_uri: Option<String>The URI of the firewall policy that this rule is associated with. This field is not applicable to VPC firewall rules and implied VPC firewall rules.
priority: Option<i32>The priority of the firewall rule.
target_service_accounts: Option<Vec<String>>The target service accounts specified by the firewall rule.
The target tags defined by the VPC firewall rule. This field is not applicable to firewall policy rules.
target_type: Option<String>Target type of the firewall rule.
uri: Option<String>The URI of the firewall rule. This field is not applicable to implied VPC firewall rules.