pub struct ForwardingRuleInfo {
pub display_name: Option<String>,
pub load_balancer_name: Option<String>,
pub matched_port_range: Option<String>,
pub matched_protocol: Option<String>,
pub network_uri: Option<String>,
pub psc_google_api_target: Option<String>,
pub psc_service_attachment_uri: Option<String>,
pub region: Option<String>,
pub target: Option<String>,
pub uri: Option<String>,
pub vip: Option<String>,
}Expand description
For display only. Metadata associated with a Compute Engine forwarding rule.
This type is not used in any activity, and only used as part of another schema.
Fields
display_name: Option<String>Name of the forwarding rule.
load_balancer_name: Option<String>Name of the load balancer the forwarding rule belongs to. Empty for forwarding rules not related to load balancers (like PSC forwarding rules).
matched_port_range: Option<String>Port range defined in the forwarding rule that matches the packet.
matched_protocol: Option<String>Protocol defined in the forwarding rule that matches the packet.
network_uri: Option<String>Network URI.
psc_google_api_target: Option<String>PSC Google API target this forwarding rule targets (if applicable).
psc_service_attachment_uri: Option<String>URI of the PSC service attachment this forwarding rule targets (if applicable).
region: Option<String>Region of the forwarding rule. Set only for regional forwarding rules.
target: Option<String>Target type of the forwarding rule.
uri: Option<String>URI of the forwarding rule.
vip: Option<String>VIP of the forwarding rule.