pub struct HybridSubnetInfo {
pub display_name: Option<String>,
pub region: Option<String>,
pub uri: Option<String>,
}Expand description
For display only. Metadata associated with a hybrid subnet.
This type is not used in any activity, and only used as part of another schema.
Fields
display_name: Option<String>Name of a hybrid subnet.
region: Option<String>Name of a Google Cloud region where the hybrid subnet is configured.
uri: Option<String>URI of a hybrid subnet.