pub struct InterconnectAttachmentInfo {
pub cloud_router_uri: Option<String>,
pub display_name: Option<String>,
pub interconnect_uri: Option<String>,
pub l2_attachment_matched_ip_address: Option<String>,
pub region: Option<String>,
pub type_: Option<String>,
pub uri: Option<String>,
}Expand description
For display only. Metadata associated with an Interconnect attachment.
This type is not used in any activity, and only used as part of another schema.
Fields
cloud_router_uri: Option<String>URI of the Cloud Router to be used for dynamic routing.
display_name: Option<String>Name of an Interconnect attachment.
interconnect_uri: Option<String>URI of the Interconnect where the Interconnect attachment is configured.
l2_attachment_matched_ip_address: Option<String>Appliance IP address that was matched for L2_DEDICATED attachments.
region: Option<String>Name of a Google Cloud region where the Interconnect attachment is configured.
type_: Option<String>The type of interconnect attachment this is.
uri: Option<String>URI of an Interconnect attachment.