pub struct RedisClusterInfo {
pub discovery_endpoint_ip_address: Option<String>,
pub display_name: Option<String>,
pub location: Option<String>,
pub network_uri: Option<String>,
pub secondary_endpoint_ip_address: Option<String>,
pub uri: Option<String>,
}Expand description
For display only. Metadata associated with a Redis Cluster.
This type is not used in any activity, and only used as part of another schema.
Fields
discovery_endpoint_ip_address: Option<String>Discovery endpoint IP address of a Redis Cluster.
display_name: Option<String>Name of a Redis Cluster.
location: Option<String>Name of the region in which the Redis Cluster is defined. For example, “us-central1”.
network_uri: Option<String>URI of the network containing the Redis Cluster endpoints in format “projects/{project_id}/global/networks/{network_id}”.
secondary_endpoint_ip_address: Option<String>Secondary endpoint IP address of a Redis Cluster.
uri: Option<String>URI of a Redis Cluster in format “projects/{project_id}/locations/{location}/clusters/{cluster_id}”