RouteInfo

Struct RouteInfo 

pub struct RouteInfo {
Show 24 fields pub advertised_route_next_hop_uri: Option<String>, pub advertised_route_source_router_uri: Option<String>, pub dest_ip_range: Option<String>, pub dest_port_ranges: Option<Vec<String>>, pub display_name: Option<String>, pub instance_tags: Option<Vec<String>>, pub ncc_hub_route_uri: Option<String>, pub ncc_hub_uri: Option<String>, pub ncc_spoke_uri: Option<String>, pub network_uri: Option<String>, pub next_hop: Option<String>, pub next_hop_network_uri: Option<String>, pub next_hop_type: Option<String>, pub next_hop_uri: Option<String>, pub originating_route_display_name: Option<String>, pub originating_route_uri: Option<String>, pub priority: Option<i32>, pub protocols: Option<Vec<String>>, pub region: Option<String>, pub route_scope: Option<String>, pub route_type: Option<String>, pub src_ip_range: Option<String>, pub src_port_ranges: Option<Vec<String>>, pub uri: Option<String>,
}
For display only. Metadata associated with a Compute Engine route.

This type is not used in any activity, and only used as part of another schema.

Fields

advertised_route_next_hop_uri: Option<String>

For ADVERTISED routes, the URI of their next hop, i.e. the URI of the hybrid endpoint (VPN tunnel, Interconnect attachment, NCC router appliance) the advertised prefix is advertised through, or URI of the source peered network. Deprecated in favor of the next_hop_uri field, not used in new tests.

advertised_route_source_router_uri: Option<String>

For ADVERTISED dynamic routes, the URI of the Cloud Router that advertised the corresponding IP prefix.

dest_ip_range: Option<String>

Destination IP range of the route.

dest_port_ranges: Option<Vec<String>>

Destination port ranges of the route. POLICY_BASED routes only.

display_name: Option<String>

Name of a route.

instance_tags: Option<Vec<String>>

Instance tags of the route.

ncc_hub_route_uri: Option<String>

For PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub, the URI of the corresponding route in NCC Hub’s routing table.

ncc_hub_uri: Option<String>

URI of the NCC Hub the route is advertised by. PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub only.

ncc_spoke_uri: Option<String>

URI of the destination NCC Spoke. PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub only.

network_uri: Option<String>

URI of a VPC network where route is located.

next_hop: Option<String>

String type of the next hop of the route (for example, “VPN tunnel”). Deprecated in favor of the next_hop_type and next_hop_uri fields, not used in new tests.

next_hop_network_uri: Option<String>

URI of a VPC network where the next hop resource is located.

next_hop_type: Option<String>

Type of next hop.

next_hop_uri: Option<String>

URI of the next hop resource.

originating_route_display_name: Option<String>

For PEERING_SUBNET, PEERING_STATIC and PEERING_DYNAMIC routes, the name of the originating SUBNET/STATIC/DYNAMIC route.

originating_route_uri: Option<String>

For PEERING_SUBNET and PEERING_STATIC routes, the URI of the originating SUBNET/STATIC route.

priority: Option<i32>

Priority of the route.

protocols: Option<Vec<String>>

Protocols of the route. POLICY_BASED routes only.

region: Option<String>

Region of the route. DYNAMIC, PEERING_DYNAMIC, POLICY_BASED and ADVERTISED routes only. If set for POLICY_BASED route, this is a region of VLAN attachments for Cloud Interconnect the route applies to.

route_scope: Option<String>

Indicates where route is applicable. Deprecated, routes with NCC_HUB scope are not included in the trace in new tests.

route_type: Option<String>

Type of route.

src_ip_range: Option<String>

Source IP address range of the route. POLICY_BASED routes only.

src_port_ranges: Option<Vec<String>>

Source port ranges of the route. POLICY_BASED routes only.

uri: Option<String>

URI of a route. SUBNET, STATIC, PEERING_SUBNET (only for peering network) and POLICY_BASED routes only.