pub struct ShowEffectiveFlowLogsConfigsResponse {
pub effective_flow_logs_configs: Option<Vec<EffectiveVpcFlowLogsConfig>>,
pub next_page_token: Option<String>,
pub unreachable: Option<Vec<String>>,
}Expand description
Response for the ShowEffectiveFlowLogsConfigs method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
effective_flow_logs_configs: Option<Vec<EffectiveVpcFlowLogsConfig>>List of Effective Vpc Flow Logs configurations.
next_page_token: Option<String>Page token to fetch the next set of configurations.
unreachable: Option<Vec<String>>Locations that could not be reached (when querying all locations with -).