SingleEdgeResponse

Struct SingleEdgeResponse 

pub struct SingleEdgeResponse {
    pub destination_egress_location: Option<EdgeLocation>,
    pub destination_router: Option<String>,
    pub probing_latency: Option<LatencyDistribution>,
    pub result: Option<String>,
    pub sent_probe_count: Option<i32>,
    pub successful_probe_count: Option<i32>,
}
Probing results for a single edge device.

This type is not used in any activity, and only used as part of another schema.

Fields

destination_egress_location: Option<EdgeLocation>

The EdgeLocation from which a packet, destined to the internet, will egress the Google network. This will only be populated for a connectivity test which has an internet destination address. The absence of this field must not be used as an indication that the destination is part of the Google network.

destination_router: Option<String>

Router name in the format ‘{router}.{metroshard}’. For example: pf01.aaa01, pr02.aaa01.

probing_latency: Option<LatencyDistribution>

Latency as measured by active probing in one direction: from the source to the destination endpoint.

result: Option<String>

The overall result of active probing for this egress device.

sent_probe_count: Option<i32>

Number of probes sent.

successful_probe_count: Option<i32>

Number of probes that reached the destination.